/*
 * XdccDownloader - ChannelJoined.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc.event;

import net.pterodactylus.irc.Connection;
import net.pterodactylus.irc.Source;

/**
 * Event that notifies a listener that a client has joined a channel.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class ChannelJoined extends AbstractChannelEvent {

	private final Source client;

	/**
	 * Creates a new channel joined event.
	 *
	 * @param connection
	 * 		The connection that joined the channel
	 * @param channel
	 * 		The channel that was joined
	 */
	public ChannelJoined(Connection connection, String channel, Source client) {
		super(connection, channel);
		this.client = client;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the client that joined the channel.
	 *
	 * @return The client that joined the channel
	 */
	public Source client() {
		return client;
	}

}
